==> stepfunctions-1.60.0-sources.jar: software/amazon/awscdk/services/stepfunctions/ActivityProps.java <==
package software.amazon.awscdk.services.stepfunctions;

/**
 * Properties for defining a new Step Functions Activity.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:13.471Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.ActivityProps")
@software.amazon.jsii.Jsii.Proxy(ActivityProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ActivityProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name for this activity.
     * <p>
     * Default: - If not supplied, a name is generated
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getActivityName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ActivityProps> {
        private java.lang.String activityName;

        /**
         * Sets the value of {@link ActivityProps#getActivityName}
         * @param activityName The name for this activity.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder activityName(java.lang.String activityName) {
            this.activityName = activityName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ActivityProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ActivityProps build() {
            return new Jsii$Proxy(activityName);
        }
    }

    /**
     * An implementation for {@link ActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ActivityProps {
        private final java.lang.String activityName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.activityName = this.jsiiGet("activityName", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String activityName) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.activityName = activityName;
        }

        @Override
        public java.lang.String getActivityName() {
            return this.activityName;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getActivityName() != null) {
                data.set("activityName", om.valueToTree(this.getActivityName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions.ActivityProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ActivityProps.Jsii$Proxy that = (ActivityProps.Jsii$Proxy) o;

            return this.activityName != null ? this.activityName.equals(that.activityName) : that.activityName == null;
        }

        @Override
        public int hashCode() {
            int result = this.activityName != null ? this.activityName.hashCode() : 0;
            return result;
        }
    }
}

==> stepfunctions-1.101.0-sources.jar: software/amazon/awscdk/services/stepfunctions/ActivityProps.java <==
package software.amazon.awscdk.services.stepfunctions;

/**
 * Properties for defining a new Step Functions Activity.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:42.238Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.ActivityProps")
@software.amazon.jsii.Jsii.Proxy(ActivityProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ActivityProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name for this activity.
     * <p>
     * Default: - If not supplied, a name is generated
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getActivityName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ActivityProps> {
        private java.lang.String activityName;

        /**
         * Sets the value of {@link ActivityProps#getActivityName}
         * @param activityName The name for this activity.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder activityName(java.lang.String activityName) {
            this.activityName = activityName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ActivityProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ActivityProps build() {
            return new Jsii$Proxy(activityName);
        }
    }

    /**
     * An implementation for {@link ActivityProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ActivityProps {
        private final java.lang.String activityName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.activityName = software.amazon.jsii.Kernel.get(this, "activityName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String activityName) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.activityName = activityName;
        }

        @Override
        public final java.lang.String getActivityName() {
            return this.activityName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getActivityName() != null) {
                data.set("activityName", om.valueToTree(this.getActivityName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions.ActivityProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ActivityProps.Jsii$Proxy that = (ActivityProps.Jsii$Proxy) o;

            return this.activityName != null ? this.activityName.equals(that.activityName) : that.activityName == null;
        }

        @Override
        public final int hashCode() {
            int result = this.activityName != null ? this.activityName.hashCode() : 0;
            return result;
        }
    }
}
